import Query, { QueryClass } from './query.js';
import '@hexadrop/types/class';
import '@hexadrop/types/nullable';
import '@hexadrop/types/primitives';

/**
 * @constant
 * @description The metadata key used to define query handlers.
 */
declare const QUERY_HANDLER_METADATA_KEY = "query-handler";
/**
 * Function that creates a QueryHandler decorator
 * @function
 * @template ResponseType - The type of the response
 * @param {...QueryClass<ResponseType, Query<ResponseType>>[]} queries - An array of Query classes
 * @returns {ClassDecorator} - A class decorator that assigns metadata to the target class
 * @throws {QueryHandlerError} - Throws an error if the target class does not implement a `run` method
 */
declare function QueryHandler<ResponseType>(...queries: QueryClass<ResponseType, Query<ResponseType>>[]): ClassDecorator;

export { QUERY_HANDLER_METADATA_KEY, QueryHandler as default };
